# -*- coding: utf-8 -*-
"""py_thorlabs_tsp.constants.py

This file contains constants used by the TSP01B DLL.

The constant definitions are taken from multiple files provided
by Thorlabs as a part of TSP01 software.

Author: Dima Pustakhod
Copyright: TU/e

"""
from ctypes import c_long

# from "IVI Foundation/WinNT/TLTSPB/Typelib/TLTSPB.odl"
# -----------------------------------------------------
VI_NULL = c_long(0)

VI_SUCCESS = 0x0


# from "IVI Foundation/Win64/Include/TLTSPB.h"
# --------------------------------------------
TLTSP_TEMPER_CHANNEL_1 = 11
TLTSP_TEMPER_CHANNEL_2 = 12
TLTSP_TEMPER_CHANNEL_3 = 13

# from "IVI Foundation/Win64/Include/TLTSP_Defines.h"
# ---------------------------------------------------
# Buffers
TLTSP_BUFFER_SIZE = 256  # General buffer size
TLTSP_ERR_DESCR_BUFFER_SIZE = 512  # Buffer size for error messages

# Attributes
TLTSP_ATTR_SET_VAL = 0
TLTSP_ATTR_MIN_VAL = 1
TLTSP_ATTR_MAX_VAL = 2
TLTSP_ATTR_DFLT_VAL = 3



# -*- coding: utf-8 -*-
"""py_thorlabs_tsp.thorlabs_tsp01b.py

This file implements a class to control Thorlabs TSP01B sensor.

It wraps limited set of low-level functions in a single class and
provides error processing.

Author: Dima Pustakhod
Copyright: TU/e
"""
from typing import Optional

from . import _errorMessage


class ThorlabsTsp01BException(Exception):
    """Base exception for Thorlabs TSP01B sensor
    """
    pass


def _process_error(instr_handle: int, error_code: int, fcn: Optional[str] = ''):
    if error_code:
        e, err_descr = _errorMessage(instr_handle, error_code)
        if e:
            raise ThorlabsTsp01BException(
                'Error obtaining error description for error'
                'code 0x{:x}: 0x{:x}.'.format(error_code, e)
            )
        else:
            raise ThorlabsTsp01BException(
                'Error 0x{:x} when calling {}: {}.'.format(
                    error_code, fcn, err_descr
                )
            )



# -*- coding: utf-8 -*-
# Distutils setup script.
#
# run as
#   python3 setup.py sdist --formats=gztar,zip
#
from setuptools import setup
from _version import __version__

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='py_thorlabs_tsp',
    packages=['py_thorlabs_tsp'],
    version=__version__,
    description='Controls for Thorlabs TSP01 temperature and humidity sensor',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Dzmitry Pustakhod, TU/e - PITC',
    author_email='d.pustakhod@tue.nl',
    url='https://gitlab.com/dimapu/py_thorlabs_tsp',
    license='MIT License',
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: Microsoft :: Windows :: Windows 7',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Scientific/Engineering',
        'Topic :: System :: Hardware',
        'Topic :: System :: Hardware :: Hardware Drivers',
    ],
)
